@@ -53,6 +53,7 @@
 #include "addrcache.h"
 #include "jpilot.h"
 #include "codeconv.h"
+#include "utils.h"
 
 #define JPILOT_DBHOME_DIR   ".jpilot"
 #define JPILOT_DBHOME_FILE  "AddressDB.pdb"
@@ -338,7 +339,7 @@ static gboolean jpilot_mark_files( JPilotFile *pilotFile ) {
 	pilotFile->pc3ModifyTime = 0;
 	pcFile = jpilot_get_pc3_file( pilotFile );
 	if( pcFile == NULL ) return retVal;
-	if( 0 == lstat( pcFile, &filestat ) ) {
+	if( 0 == g_lstat( pcFile, &filestat ) ) {
 		pilotFile->havePC3 = TRUE;
 		pilotFile->pc3ModifyTime = filestat.st_mtime;
 		retVal = TRUE;
@@ -366,7 +367,7 @@ static gboolean jpilot_check_files( JPilotFile *pilotFile ) {
 	pcFile = jpilot_get_pc3_file( pilotFile );
 	if( pcFile == NULL ) return FALSE;
 
-	if( 0 == lstat( pcFile, &filestat ) ) {
+	if( 0 == g_lstat( pcFile, &filestat ) ) {
 		if( filestat.st_mtime == pilotFile->pc3ModifyTime ) retVal = FALSE;
 	}
 	g_free( pcFile );
@@ -643,7 +644,7 @@ static gint jpilot_get_file_info( JPilotFile *pilotFile, unsigned char **buf, in
 	*buf_size=0;
 
 	if( pilotFile->path ) {
-		in = fopen( pilotFile->path, "rb" );
+		in = g_fopen( pilotFile->path, "rb" );
 		if( !in ) {
 			return MGU_OPEN_FILE;
 		}
@@ -825,7 +826,7 @@ static gint jpilot_read_db_files( JPilotFile *pilotFile, GList **records ) {
 		return MGU_BAD_ARGS;
 	}
 
-	in = fopen( pilotFile->path, "rb" );
+	in = g_fopen( pilotFile->path, "rb" );
 	if (!in) {
 		return MGU_OPEN_FILE;
 	}
@@ -942,7 +943,7 @@ static gint jpilot_read_db_files( JPilotFile *pilotFile, GList **records ) {
 	/* Read the PC3 file, if present */
 	pcFile = jpilot_get_pc3_file( pilotFile );
 	if( pcFile == NULL ) return MGU_SUCCESS;
-	pc_in = fopen( pcFile, "rb");
+	pc_in = g_fopen( pcFile, "rb");
 	g_free( pcFile );
 
 	if( pc_in == NULL ) {
@@ -1048,8 +1049,8 @@ static void jpilot_load_address( JPilotFile *pilotFile, buf_rec *buf, ItemFolder
 
 		if( convert_charcode ) {
 			gchar *nameConv;
-			nameConv = g_strdup( fullName );
-			conv_sjistoeuc( fullName, FULLNAME_BUFSIZE, nameConv );
+			nameConv = conv_codeset_strdup( fullName, CS_SHIFT_JIS, CS_INTERNAL );
+			strncpy2( fullName, nameConv, FULLNAME_BUFSIZE );
 			g_free( nameConv );
 		}
 
@@ -1096,7 +1097,6 @@ static void jpilot_load_address( JPilotFile *pilotFile, buf_rec *buf, ItemFolder
 		/* Add entry for each custom label */
 		node = pilotFile->labelInd;
 		while( node ) {
-			gchar convertBuff[ JPILOT_LEN_LABEL ];
 			gint ind;
 
 			ind = GPOINTER_TO_INT( node->data );
@@ -1115,8 +1115,10 @@ static void jpilot_load_address( JPilotFile *pilotFile, buf_rec *buf, ItemFolder
 					addritem_email_set_address( email, bufEMail );
 
 					if( convert_charcode ) {
-						conv_sjistoeuc( convertBuff, JPILOT_LEN_LABEL, ai->labels[ind] );
+						gchar *convertBuff;
+						convertBuff = conv_codeset_strdup( ai->labels[ind], CS_SHIFT_JIS, CS_INTERNAL );
 						addritem_email_set_remarks( email, convertBuff );
+						g_free( convertBuff );
 					}
 					else {
 						addritem_email_set_remarks( email, ai->labels[ind] );
@@ -1283,11 +1285,13 @@ static gboolean jpilot_setup_labels( JPilotFile *pilotFile ) {
 				gchar convertBuff[ JPILOT_LEN_LABEL ];
 
 				if( convert_charcode ) {
-					conv_sjistoeuc( convertBuff, JPILOT_LEN_LABEL, labelName );
+					labelName = conv_codeset_strdup( labelName, CS_SHIFT_JIS, CS_INTERNAL );
+					strncpy2( convertBuff, labelName, JPILOT_LEN_LABEL );
+					g_free( labelName );
 					labelName = convertBuff;
 				}
 
-				if( g_strcasecmp( labelName, lbl ) == 0 ) {
+				if( g_ascii_strcasecmp( labelName, lbl ) == 0 ) {
 					ind = i;
 					break;
 				}
@@ -1312,14 +1316,15 @@ GList *jpilot_load_label( JPilotFile *pilotFile, GList *labelList ) {
 		struct AddressAppInfo *ai = & pilotFile->addrInfo;
 		for( i = 0; i < JPILOT_NUM_LABELS; i++ ) {
 			gchar *labelName = ai->labels[i];
-			gchar convertBuff[JPILOT_LEN_LABEL];
 
 			if( labelName ) {
 				if( convert_charcode ) {
-					conv_sjistoeuc( convertBuff, JPILOT_LEN_LABEL, labelName );
-					labelName = convertBuff;
+					labelName = conv_codeset_strdup( labelName, CS_SHIFT_JIS, CS_INTERNAL );
 				}
-				labelList = g_list_append( labelList, g_strdup( labelName ) );
+				else {
+					labelName = g_strdup( labelName );
+				}
+				labelList = g_list_append( labelList, labelName );
 			}
 			else {
 				labelList = g_list_append( labelList, g_strdup( "" ) );
@@ -1381,7 +1386,6 @@ GList *jpilot_load_phone_label( JPilotFile *pilotFile, GList *labelList ) {
 */
 GList *jpilot_load_custom_label( JPilotFile *pilotFile, GList *labelList ) {
 	gint i;
-	char convertBuff[JPILOT_LEN_LABEL];
 
 	g_return_val_if_fail( pilotFile != NULL, NULL );
 
@@ -1394,10 +1398,12 @@ GList *jpilot_load_custom_label( JPilotFile *pilotFile, GList *labelList ) {
 				g_strchug( labelName );
 				if( *labelName != '\0' ) {
 					if( convert_charcode ) {
-						conv_sjistoeuc( convertBuff, JPILOT_LEN_LABEL, labelName );
-						labelName = convertBuff;
+						labelName = conv_codeset_strdup( labelName, CS_SHIFT_JIS, CS_INTERNAL );
 					}
-					labelList = g_list_append( labelList, g_strdup( labelName ) );
+					else {
+						labelName = g_strdup( labelName );
+					}
+					labelList = g_list_append( labelList, labelName );
 				}
 			}
 		}
@@ -1442,9 +1448,10 @@ static void jpilot_build_category_list( JPilotFile *pilotFile ) {
 		ItemFolder *folder = addritem_create_item_folder();
 
 		if( convert_charcode ) {
-			gchar catName[ JPILOT_LEN_CATEG ];
-			conv_sjistoeuc( catName, JPILOT_LEN_CATEG, cat->name[i] );
+			gchar *catName;
+			catName = conv_codeset_strdup( cat->name[i], CS_SHIFT_JIS, CS_INTERNAL );
 			addritem_folder_set_name( folder, catName );
+			g_free( catName );
 		}
 		else {
 			addritem_folder_set_name( folder, cat->name[i] );
@@ -1500,18 +1507,11 @@ static void jpilot_remove_empty( JPilotFile *pilotFile ) {
 * ============================================================================================
 */
 gint jpilot_read_data( JPilotFile *pilotFile ) {
-	const gchar *cur_locale;
-
 	name_order = FAMILY_LAST;
 	convert_charcode = FALSE;
 
-	cur_locale = conv_get_current_locale();
-
-	if( g_strncasecmp( cur_locale, "ja", 2 ) == 0 ) {
+	if( conv_is_ja_locale() ) {
 		name_order = FAMILY_FIRST;
-	}
-
-	if( conv_get_current_charset() == C_EUC_JP ) {
 		convert_charcode = TRUE;
 	}
 
@@ -1580,7 +1580,7 @@ gint jpilot_check_label( struct AddressAppInfo *ai, gchar *lblCheck ) {
 		lblName = ai->labels[i];
 		if( lblName ) {
 			if( strlen( lblName ) ) {
-				if( g_strcasecmp( lblName, lblCheck ) == 0 ) return i;
+				if( g_ascii_strcasecmp( lblName, lblCheck ) == 0 ) return i;
 			}
 		}
 	}
@@ -1620,12 +1620,12 @@ gboolean jpilot_validate( const JPilotFile *pilotFile ) {
 * no home. Filename should be g_free() when done.
 */
 gchar *jpilot_find_pilotdb( void ) {
-	gchar *homedir;
+	const gchar *homedir;
 	gchar str[ WORK_BUFLEN ];
 	gint len;
 	FILE *fp;
 
-	homedir = g_get_home_dir();
+	homedir = get_home_dir();
 	if( ! homedir ) return g_strdup( "" );
 
 	strcpy( str, homedir );
@@ -1641,7 +1641,7 @@ gchar *jpilot_find_pilotdb( void ) {
 	strcat( str, JPILOT_DBHOME_FILE );
 
 	/* Attempt to open */
-	if( ( fp = fopen( str, "rb" ) ) != NULL ) {
+	if( ( fp = g_fopen( str, "rb" ) ) != NULL ) {
 		fclose( fp );
 	}
 	else {
@@ -1685,7 +1685,7 @@ gboolean jpilot_test_custom_label( JPilotFile *pilotFile, const gchar *labelName
 	if( labelName ) {
 		node = pilotFile->customLabels;
 		while( node ) {
-			if( g_strcasecmp( labelName, node->data ) == 0 ) {
+			if( g_ascii_strcasecmp( labelName, node->data ) == 0 ) {
 				retVal = TRUE;
 				break;
 			}
